
'Client and server classes corresponding to protobuf-defined services.'
import grpc
from ....cosmos.feegrant.v1beta1 import query_pb2 as cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2

class QueryStub(object):
    'Query defines the gRPC querier service.\n    '

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.Allowance = channel.unary_unary('/cosmos.feegrant.v1beta1.Query/Allowance', request_serializer=cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowanceRequest.SerializeToString, response_deserializer=cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowanceResponse.FromString)
        self.Allowances = channel.unary_unary('/cosmos.feegrant.v1beta1.Query/Allowances', request_serializer=cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowancesRequest.SerializeToString, response_deserializer=cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowancesResponse.FromString)

class QueryServicer(object):
    'Query defines the gRPC querier service.\n    '

    def Allowance(self, request, context):
        'Allowance returns fee granted to the grantee by the granter.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Allowances(self, request, context):
        'Allowances returns all the grants for address.\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'Allowance': grpc.unary_unary_rpc_method_handler(servicer.Allowance, request_deserializer=cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowanceRequest.FromString, response_serializer=cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowanceResponse.SerializeToString), 'Allowances': grpc.unary_unary_rpc_method_handler(servicer.Allowances, request_deserializer=cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowancesRequest.FromString, response_serializer=cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowancesResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('cosmos.feegrant.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Query defines the gRPC querier service.\n    '

    @staticmethod
    def Allowance(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.feegrant.v1beta1.Query/Allowance', cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowanceRequest.SerializeToString, cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowanceResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Allowances(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.feegrant.v1beta1.Query/Allowances', cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowancesRequest.SerializeToString, cosmos_dot_feegrant_dot_v1beta1_dot_query__pb2.QueryAllowancesResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%sentinel/subscription/v2/payout.proto\x12\x18sentinel.subscription.v2\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xbb\x01\n\x06Payout\x12\x12\n\x02id\x18\x01 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07address\x18\x02 \x01(\t\x12\x14\n\x0cnode_address\x18\x03 \x01(\t\x12\r\n\x05hours\x18\x04 \x01(\x03\x12.\n\x05price\x18\x05 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x127\n\ttimestamp\x18\x06 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01B?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.payout_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _PAYOUT.fields_by_name['id']._options = None
    _PAYOUT.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _PAYOUT.fields_by_name['price']._options = None
    _PAYOUT.fields_by_name['price']._serialized_options = b'\xc8\xde\x1f\x00'
    _PAYOUT.fields_by_name['timestamp']._options = None
    _PAYOUT.fields_by_name['timestamp']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _PAYOUT._serialized_start = 155
    _PAYOUT._serialized_end = 342




from gogoproto import gogo_pb2 as _gogo_pb2
from cosmos.slashing.v1beta1 import slashing_pb2 as _slashing_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ['missed_blocks', 'params', 'signing_infos']
    MISSED_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    SIGNING_INFOS_FIELD_NUMBER: _ClassVar[int]
    missed_blocks: _containers.RepeatedCompositeFieldContainer[ValidatorMissedBlocks]
    params: _slashing_pb2.Params
    signing_infos: _containers.RepeatedCompositeFieldContainer[SigningInfo]

    def __init__(self, params: _Optional[_Union[(_slashing_pb2.Params, _Mapping)]]=..., signing_infos: _Optional[_Iterable[_Union[(SigningInfo, _Mapping)]]]=..., missed_blocks: _Optional[_Iterable[_Union[(ValidatorMissedBlocks, _Mapping)]]]=...) -> None:
        ...

class MissedBlock(_message.Message):
    __slots__ = ['index', 'missed']
    INDEX_FIELD_NUMBER: _ClassVar[int]
    MISSED_FIELD_NUMBER: _ClassVar[int]
    index: int
    missed: bool

    def __init__(self, index: _Optional[int]=..., missed: bool=...) -> None:
        ...

class SigningInfo(_message.Message):
    __slots__ = ['address', 'validator_signing_info']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SIGNING_INFO_FIELD_NUMBER: _ClassVar[int]
    address: str
    validator_signing_info: _slashing_pb2.ValidatorSigningInfo

    def __init__(self, address: _Optional[str]=..., validator_signing_info: _Optional[_Union[(_slashing_pb2.ValidatorSigningInfo, _Mapping)]]=...) -> None:
        ...

class ValidatorMissedBlocks(_message.Message):
    __slots__ = ['address', 'missed_blocks']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    MISSED_BLOCKS_FIELD_NUMBER: _ClassVar[int]
    address: str
    missed_blocks: _containers.RepeatedCompositeFieldContainer[MissedBlock]

    def __init__(self, address: _Optional[str]=..., missed_blocks: _Optional[_Iterable[_Union[(MissedBlock, _Mapping)]]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....sentinel.subscription.v2 import allocation_pb2 as sentinel_dot_subscription_dot_v2_dot_allocation__pb2
from ....sentinel.subscription.v2 import params_pb2 as sentinel_dot_subscription_dot_v2_dot_params__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&sentinel/subscription/v2/genesis.proto\x12\x18sentinel.subscription.v2\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a)sentinel/subscription/v2/allocation.proto\x1a%sentinel/subscription/v2/params.proto"\x82\x01\n\x13GenesisSubscription\x12*\n\x0csubscription\x18\x01 \x01(\x0b2\x14.google.protobuf.Any\x12?\n\x0ballocations\x18\x02 \x03(\x0b2$.sentinel.subscription.v2.AllocationB\x04\xc8\xde\x1f\x00"\x92\x01\n\x0cGenesisState\x12J\n\rsubscriptions\x18\x01 \x03(\x0b2-.sentinel.subscription.v2.GenesisSubscriptionB\x04\xc8\xde\x1f\x00\x126\n\x06params\x18\x02 \x01(\x0b2 .sentinel.subscription.v2.ParamsB\x04\xc8\xde\x1f\x00B?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.genesis_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _GENESISSUBSCRIPTION.fields_by_name['allocations']._options = None
    _GENESISSUBSCRIPTION.fields_by_name['allocations']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['subscriptions']._options = None
    _GENESISSTATE.fields_by_name['subscriptions']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSTATE.fields_by_name['params']._options = None
    _GENESISSTATE.fields_by_name['params']._serialized_options = b'\xc8\xde\x1f\x00'
    _GENESISSUBSCRIPTION._serialized_start = 200
    _GENESISSUBSCRIPTION._serialized_end = 330
    _GENESISSTATE._serialized_start = 333
    _GENESISSTATE._serialized_end = 479




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...tendermint.crypto import proof_pb2 as tendermint_dot_crypto_dot_proof__pb2
from ...tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from ...tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2
from ...tendermint.types import params_pb2 as tendermint_dot_types_dot_params__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1btendermint/abci/types.proto\x12\x0ftendermint.abci\x1a\x1dtendermint/crypto/proof.proto\x1a\x1ctendermint/types/types.proto\x1a\x1ctendermint/crypto/keys.proto\x1a\x1dtendermint/types/params.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto"\xea\x06\n\x07Request\x12,\n\x04echo\x18\x01 \x01(\x0b2\x1c.tendermint.abci.RequestEchoH\x00\x12.\n\x05flush\x18\x02 \x01(\x0b2\x1d.tendermint.abci.RequestFlushH\x00\x12,\n\x04info\x18\x03 \x01(\x0b2\x1c.tendermint.abci.RequestInfoH\x00\x127\n\nset_option\x18\x04 \x01(\x0b2!.tendermint.abci.RequestSetOptionH\x00\x127\n\ninit_chain\x18\x05 \x01(\x0b2!.tendermint.abci.RequestInitChainH\x00\x12.\n\x05query\x18\x06 \x01(\x0b2\x1d.tendermint.abci.RequestQueryH\x00\x129\n\x0bbegin_block\x18\x07 \x01(\x0b2".tendermint.abci.RequestBeginBlockH\x00\x123\n\x08check_tx\x18\x08 \x01(\x0b2\x1f.tendermint.abci.RequestCheckTxH\x00\x127\n\ndeliver_tx\x18\t \x01(\x0b2!.tendermint.abci.RequestDeliverTxH\x00\x125\n\tend_block\x18\n \x01(\x0b2 .tendermint.abci.RequestEndBlockH\x00\x120\n\x06commit\x18\x0b \x01(\x0b2\x1e.tendermint.abci.RequestCommitH\x00\x12?\n\x0elist_snapshots\x18\x0c \x01(\x0b2%.tendermint.abci.RequestListSnapshotsH\x00\x12?\n\x0eoffer_snapshot\x18\r \x01(\x0b2%.tendermint.abci.RequestOfferSnapshotH\x00\x12H\n\x13load_snapshot_chunk\x18\x0e \x01(\x0b2).tendermint.abci.RequestLoadSnapshotChunkH\x00\x12J\n\x14apply_snapshot_chunk\x18\x0f \x01(\x0b2*.tendermint.abci.RequestApplySnapshotChunkH\x00B\x07\n\x05value"\x1e\n\x0bRequestEcho\x12\x0f\n\x07message\x18\x01 \x01(\t"\x0e\n\x0cRequestFlush"J\n\x0bRequestInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x15\n\rblock_version\x18\x02 \x01(\x04\x12\x13\n\x0bp2p_version\x18\x03 \x01(\x04".\n\x10RequestSetOption\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"\x81\x02\n\x10RequestInitChain\x122\n\x04time\x18\x01 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x10\n\x08chain_id\x18\x02 \x01(\t\x12:\n\x10consensus_params\x18\x03 \x01(\x0b2 .tendermint.abci.ConsensusParams\x12:\n\nvalidators\x18\x04 \x03(\x0b2 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x17\n\x0fapp_state_bytes\x18\x05 \x01(\x0c\x12\x16\n\x0einitial_height\x18\x06 \x01(\x03"I\n\x0cRequestQuery\x12\x0c\n\x04data\x18\x01 \x01(\x0c\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\r\n\x05prove\x18\x04 \x01(\x08"\xd1\x01\n\x11RequestBeginBlock\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12.\n\x06header\x18\x02 \x01(\x0b2\x18.tendermint.types.HeaderB\x04\xc8\xde\x1f\x00\x12?\n\x10last_commit_info\x18\x03 \x01(\x0b2\x1f.tendermint.abci.LastCommitInfoB\x04\xc8\xde\x1f\x00\x12=\n\x14byzantine_validators\x18\x04 \x03(\x0b2\x19.tendermint.abci.EvidenceB\x04\xc8\xde\x1f\x00"H\n\x0eRequestCheckTx\x12\n\n\x02tx\x18\x01 \x01(\x0c\x12*\n\x04type\x18\x02 \x01(\x0e2\x1c.tendermint.abci.CheckTxType"\x1e\n\x10RequestDeliverTx\x12\n\n\x02tx\x18\x01 \x01(\x0c"!\n\x0fRequestEndBlock\x12\x0e\n\x06height\x18\x01 \x01(\x03"\x0f\n\rRequestCommit"\x16\n\x14RequestListSnapshots"U\n\x14RequestOfferSnapshot\x12+\n\x08snapshot\x18\x01 \x01(\x0b2\x19.tendermint.abci.Snapshot\x12\x10\n\x08app_hash\x18\x02 \x01(\x0c"I\n\x18RequestLoadSnapshotChunk\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06format\x18\x02 \x01(\r\x12\r\n\x05chunk\x18\x03 \x01(\r"I\n\x19RequestApplySnapshotChunk\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05chunk\x18\x02 \x01(\x0c\x12\x0e\n\x06sender\x18\x03 \x01(\t"\xb3\x07\n\x08Response\x127\n\texception\x18\x01 \x01(\x0b2".tendermint.abci.ResponseExceptionH\x00\x12-\n\x04echo\x18\x02 \x01(\x0b2\x1d.tendermint.abci.ResponseEchoH\x00\x12/\n\x05flush\x18\x03 \x01(\x0b2\x1e.tendermint.abci.ResponseFlushH\x00\x12-\n\x04info\x18\x04 \x01(\x0b2\x1d.tendermint.abci.ResponseInfoH\x00\x128\n\nset_option\x18\x05 \x01(\x0b2".tendermint.abci.ResponseSetOptionH\x00\x128\n\ninit_chain\x18\x06 \x01(\x0b2".tendermint.abci.ResponseInitChainH\x00\x12/\n\x05query\x18\x07 \x01(\x0b2\x1e.tendermint.abci.ResponseQueryH\x00\x12:\n\x0bbegin_block\x18\x08 \x01(\x0b2#.tendermint.abci.ResponseBeginBlockH\x00\x124\n\x08check_tx\x18\t \x01(\x0b2 .tendermint.abci.ResponseCheckTxH\x00\x128\n\ndeliver_tx\x18\n \x01(\x0b2".tendermint.abci.ResponseDeliverTxH\x00\x126\n\tend_block\x18\x0b \x01(\x0b2!.tendermint.abci.ResponseEndBlockH\x00\x121\n\x06commit\x18\x0c \x01(\x0b2\x1f.tendermint.abci.ResponseCommitH\x00\x12@\n\x0elist_snapshots\x18\r \x01(\x0b2&.tendermint.abci.ResponseListSnapshotsH\x00\x12@\n\x0eoffer_snapshot\x18\x0e \x01(\x0b2&.tendermint.abci.ResponseOfferSnapshotH\x00\x12I\n\x13load_snapshot_chunk\x18\x0f \x01(\x0b2*.tendermint.abci.ResponseLoadSnapshotChunkH\x00\x12K\n\x14apply_snapshot_chunk\x18\x10 \x01(\x0b2+.tendermint.abci.ResponseApplySnapshotChunkH\x00B\x07\n\x05value""\n\x11ResponseException\x12\r\n\x05error\x18\x01 \x01(\t"\x1f\n\x0cResponseEcho\x12\x0f\n\x07message\x18\x01 \x01(\t"\x0f\n\rResponseFlush"z\n\x0cResponseInfo\x12\x0c\n\x04data\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x13\n\x0bapp_version\x18\x03 \x01(\x04\x12\x19\n\x11last_block_height\x18\x04 \x01(\x03\x12\x1b\n\x13last_block_app_hash\x18\x05 \x01(\x0c"<\n\x11ResponseSetOption\x12\x0c\n\x04code\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t"\x9d\x01\n\x11ResponseInitChain\x12:\n\x10consensus_params\x18\x01 \x01(\x0b2 .tendermint.abci.ConsensusParams\x12:\n\nvalidators\x18\x02 \x03(\x0b2 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12\x10\n\x08app_hash\x18\x03 \x01(\x0c"\xb6\x01\n\rResponseQuery\x12\x0c\n\x04code\x18\x01 \x01(\r\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\r\n\x05index\x18\x05 \x01(\x03\x12\x0b\n\x03key\x18\x06 \x01(\x0c\x12\r\n\x05value\x18\x07 \x01(\x0c\x12.\n\tproof_ops\x18\x08 \x01(\x0b2\x1b.tendermint.crypto.ProofOps\x12\x0e\n\x06height\x18\t \x01(\x03\x12\x11\n\tcodespace\x18\n \x01(\t"V\n\x12ResponseBeginBlock\x12@\n\x06events\x18\x01 \x03(\x0b2\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10events,omitempty"\xd9\x01\n\x0fResponseCheckTx\x12\x0c\n\x04code\x18\x01 \x01(\r\x12\x0c\n\x04data\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12@\n\x06events\x18\x07 \x03(\x0b2\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10events,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t"\xdb\x01\n\x11ResponseDeliverTx\x12\x0c\n\x04code\x18\x01 \x01(\r\x12\x0c\n\x04data\x18\x02 \x01(\x0c\x12\x0b\n\x03log\x18\x03 \x01(\t\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x1e\n\ngas_wanted\x18\x05 \x01(\x03R\ngas_wanted\x12\x1a\n\x08gas_used\x18\x06 \x01(\x03R\x08gas_used\x12@\n\x06events\x18\x07 \x03(\x0b2\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10events,omitempty\x12\x11\n\tcodespace\x18\x08 \x01(\t"\xda\x01\n\x10ResponseEndBlock\x12A\n\x11validator_updates\x18\x01 \x03(\x0b2 .tendermint.abci.ValidatorUpdateB\x04\xc8\xde\x1f\x00\x12A\n\x17consensus_param_updates\x18\x02 \x01(\x0b2 .tendermint.abci.ConsensusParams\x12@\n\x06events\x18\x03 \x03(\x0b2\x16.tendermint.abci.EventB\x18\xc8\xde\x1f\x00\xea\xde\x1f\x10events,omitempty"5\n\x0eResponseCommit\x12\x0c\n\x04data\x18\x02 \x01(\x0c\x12\x15\n\rretain_height\x18\x03 \x01(\x03"E\n\x15ResponseListSnapshots\x12,\n\tsnapshots\x18\x01 \x03(\x0b2\x19.tendermint.abci.Snapshot"\xb6\x01\n\x15ResponseOfferSnapshot\x12=\n\x06result\x18\x01 \x01(\x0e2-.tendermint.abci.ResponseOfferSnapshot.Result"^\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06ACCEPT\x10\x01\x12\t\n\x05ABORT\x10\x02\x12\n\n\x06REJECT\x10\x03\x12\x11\n\rREJECT_FORMAT\x10\x04\x12\x11\n\rREJECT_SENDER\x10\x05"*\n\x19ResponseLoadSnapshotChunk\x12\r\n\x05chunk\x18\x01 \x01(\x0c"\xf2\x01\n\x1aResponseApplySnapshotChunk\x12B\n\x06result\x18\x01 \x01(\x0e22.tendermint.abci.ResponseApplySnapshotChunk.Result\x12\x16\n\x0erefetch_chunks\x18\x02 \x03(\r\x12\x16\n\x0ereject_senders\x18\x03 \x03(\t"`\n\x06Result\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06ACCEPT\x10\x01\x12\t\n\x05ABORT\x10\x02\x12\t\n\x05RETRY\x10\x03\x12\x12\n\x0eRETRY_SNAPSHOT\x10\x04\x12\x13\n\x0fREJECT_SNAPSHOT\x10\x05"\xda\x01\n\x0fConsensusParams\x12+\n\x05block\x18\x01 \x01(\x0b2\x1c.tendermint.abci.BlockParams\x122\n\x08evidence\x18\x02 \x01(\x0b2 .tendermint.types.EvidenceParams\x124\n\tvalidator\x18\x03 \x01(\x0b2!.tendermint.types.ValidatorParams\x120\n\x07version\x18\x04 \x01(\x0b2\x1f.tendermint.types.VersionParams"1\n\x0bBlockParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x03\x12\x0f\n\x07max_gas\x18\x02 \x01(\x03"O\n\x0eLastCommitInfo\x12\r\n\x05round\x18\x01 \x01(\x05\x12.\n\x05votes\x18\x02 \x03(\x0b2\x19.tendermint.abci.VoteInfoB\x04\xc8\xde\x1f\x00"h\n\x05Event\x12\x0c\n\x04type\x18\x01 \x01(\t\x12Q\n\nattributes\x18\x02 \x03(\x0b2\x1f.tendermint.abci.EventAttributeB\x1c\xc8\xde\x1f\x00\xea\xde\x1f\x14attributes,omitempty";\n\x0eEventAttribute\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\r\n\x05index\x18\x03 \x01(\x08"o\n\x08TxResult\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05index\x18\x02 \x01(\r\x12\n\n\x02tx\x18\x03 \x01(\x0c\x128\n\x06result\x18\x04 \x01(\x0b2".tendermint.abci.ResponseDeliverTxB\x04\xc8\xde\x1f\x00"+\n\tValidator\x12\x0f\n\x07address\x18\x01 \x01(\x0c\x12\r\n\x05power\x18\x03 \x01(\x03"U\n\x0fValidatorUpdate\x123\n\x07pub_key\x18\x01 \x01(\x0b2\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\r\n\x05power\x18\x02 \x01(\x03"Z\n\x08VoteInfo\x123\n\tvalidator\x18\x01 \x01(\x0b2\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x19\n\x11signed_last_block\x18\x02 \x01(\x08"\xcc\x01\n\x08Evidence\x12+\n\x04type\x18\x01 \x01(\x0e2\x1d.tendermint.abci.EvidenceType\x123\n\tvalidator\x18\x02 \x01(\x0b2\x1a.tendermint.abci.ValidatorB\x04\xc8\xde\x1f\x00\x12\x0e\n\x06height\x18\x03 \x01(\x03\x122\n\x04time\x18\x04 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x1a\n\x12total_voting_power\x18\x05 \x01(\x03"Z\n\x08Snapshot\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x0e\n\x06format\x18\x02 \x01(\r\x12\x0e\n\x06chunks\x18\x03 \x01(\r\x12\x0c\n\x04hash\x18\x04 \x01(\x0c\x12\x10\n\x08metadata\x18\x05 \x01(\x0c*9\n\x0bCheckTxType\x12\x10\n\x03NEW\x10\x00\x1a\x07\x8a\x9d \x03New\x12\x18\n\x07RECHECK\x10\x01\x1a\x0b\x8a\x9d \x07Recheck*H\n\x0cEvidenceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0eDUPLICATE_VOTE\x10\x01\x12\x17\n\x13LIGHT_CLIENT_ATTACK\x10\x022\x83\n\n\x0fABCIApplication\x12C\n\x04Echo\x12\x1c.tendermint.abci.RequestEcho\x1a\x1d.tendermint.abci.ResponseEcho\x12F\n\x05Flush\x12\x1d.tendermint.abci.RequestFlush\x1a\x1e.tendermint.abci.ResponseFlush\x12C\n\x04Info\x12\x1c.tendermint.abci.RequestInfo\x1a\x1d.tendermint.abci.ResponseInfo\x12R\n\tSetOption\x12!.tendermint.abci.RequestSetOption\x1a".tendermint.abci.ResponseSetOption\x12R\n\tDeliverTx\x12!.tendermint.abci.RequestDeliverTx\x1a".tendermint.abci.ResponseDeliverTx\x12L\n\x07CheckTx\x12\x1f.tendermint.abci.RequestCheckTx\x1a .tendermint.abci.ResponseCheckTx\x12F\n\x05Query\x12\x1d.tendermint.abci.RequestQuery\x1a\x1e.tendermint.abci.ResponseQuery\x12I\n\x06Commit\x12\x1e.tendermint.abci.RequestCommit\x1a\x1f.tendermint.abci.ResponseCommit\x12R\n\tInitChain\x12!.tendermint.abci.RequestInitChain\x1a".tendermint.abci.ResponseInitChain\x12U\n\nBeginBlock\x12".tendermint.abci.RequestBeginBlock\x1a#.tendermint.abci.ResponseBeginBlock\x12O\n\x08EndBlock\x12 .tendermint.abci.RequestEndBlock\x1a!.tendermint.abci.ResponseEndBlock\x12^\n\rListSnapshots\x12%.tendermint.abci.RequestListSnapshots\x1a&.tendermint.abci.ResponseListSnapshots\x12^\n\rOfferSnapshot\x12%.tendermint.abci.RequestOfferSnapshot\x1a&.tendermint.abci.ResponseOfferSnapshot\x12j\n\x11LoadSnapshotChunk\x12).tendermint.abci.RequestLoadSnapshotChunk\x1a*.tendermint.abci.ResponseLoadSnapshotChunk\x12m\n\x12ApplySnapshotChunk\x12*.tendermint.abci.RequestApplySnapshotChunk\x1a+.tendermint.abci.ResponseApplySnapshotChunkB-Z+github.com/tendermint/tendermint/abci/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.abci.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z+github.com/tendermint/tendermint/abci/types'
    _CHECKTXTYPE.values_by_name['NEW']._options = None
    _CHECKTXTYPE.values_by_name['NEW']._serialized_options = b'\x8a\x9d \x03New'
    _CHECKTXTYPE.values_by_name['RECHECK']._options = None
    _CHECKTXTYPE.values_by_name['RECHECK']._serialized_options = b'\x8a\x9d \x07Recheck'
    _REQUESTINITCHAIN.fields_by_name['time']._options = None
    _REQUESTINITCHAIN.fields_by_name['time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _REQUESTINITCHAIN.fields_by_name['validators']._options = None
    _REQUESTINITCHAIN.fields_by_name['validators']._serialized_options = b'\xc8\xde\x1f\x00'
    _REQUESTBEGINBLOCK.fields_by_name['header']._options = None
    _REQUESTBEGINBLOCK.fields_by_name['header']._serialized_options = b'\xc8\xde\x1f\x00'
    _REQUESTBEGINBLOCK.fields_by_name['last_commit_info']._options = None
    _REQUESTBEGINBLOCK.fields_by_name['last_commit_info']._serialized_options = b'\xc8\xde\x1f\x00'
    _REQUESTBEGINBLOCK.fields_by_name['byzantine_validators']._options = None
    _REQUESTBEGINBLOCK.fields_by_name['byzantine_validators']._serialized_options = b'\xc8\xde\x1f\x00'
    _RESPONSEINITCHAIN.fields_by_name['validators']._options = None
    _RESPONSEINITCHAIN.fields_by_name['validators']._serialized_options = b'\xc8\xde\x1f\x00'
    _RESPONSEBEGINBLOCK.fields_by_name['events']._options = None
    _RESPONSEBEGINBLOCK.fields_by_name['events']._serialized_options = b'\xc8\xde\x1f\x00\xea\xde\x1f\x10events,omitempty'
    _RESPONSECHECKTX.fields_by_name['events']._options = None
    _RESPONSECHECKTX.fields_by_name['events']._serialized_options = b'\xc8\xde\x1f\x00\xea\xde\x1f\x10events,omitempty'
    _RESPONSEDELIVERTX.fields_by_name['events']._options = None
    _RESPONSEDELIVERTX.fields_by_name['events']._serialized_options = b'\xc8\xde\x1f\x00\xea\xde\x1f\x10events,omitempty'
    _RESPONSEENDBLOCK.fields_by_name['validator_updates']._options = None
    _RESPONSEENDBLOCK.fields_by_name['validator_updates']._serialized_options = b'\xc8\xde\x1f\x00'
    _RESPONSEENDBLOCK.fields_by_name['events']._options = None
    _RESPONSEENDBLOCK.fields_by_name['events']._serialized_options = b'\xc8\xde\x1f\x00\xea\xde\x1f\x10events,omitempty'
    _LASTCOMMITINFO.fields_by_name['votes']._options = None
    _LASTCOMMITINFO.fields_by_name['votes']._serialized_options = b'\xc8\xde\x1f\x00'
    _EVENT.fields_by_name['attributes']._options = None
    _EVENT.fields_by_name['attributes']._serialized_options = b'\xc8\xde\x1f\x00\xea\xde\x1f\x14attributes,omitempty'
    _TXRESULT.fields_by_name['result']._options = None
    _TXRESULT.fields_by_name['result']._serialized_options = b'\xc8\xde\x1f\x00'
    _VALIDATORUPDATE.fields_by_name['pub_key']._options = None
    _VALIDATORUPDATE.fields_by_name['pub_key']._serialized_options = b'\xc8\xde\x1f\x00'
    _VOTEINFO.fields_by_name['validator']._options = None
    _VOTEINFO.fields_by_name['validator']._serialized_options = b'\xc8\xde\x1f\x00'
    _EVIDENCE.fields_by_name['validator']._options = None
    _EVIDENCE.fields_by_name['validator']._serialized_options = b'\xc8\xde\x1f\x00'
    _EVIDENCE.fields_by_name['time']._options = None
    _EVIDENCE.fields_by_name['time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _CHECKTXTYPE._serialized_start = 6314
    _CHECKTXTYPE._serialized_end = 6371
    _EVIDENCETYPE._serialized_start = 6373
    _EVIDENCETYPE._serialized_end = 6445
    _REQUEST._serialized_start = 226
    _REQUEST._serialized_end = 1100
    _REQUESTECHO._serialized_start = 1102
    _REQUESTECHO._serialized_end = 1132
    _REQUESTFLUSH._serialized_start = 1134
    _REQUESTFLUSH._serialized_end = 1148
    _REQUESTINFO._serialized_start = 1150
    _REQUESTINFO._serialized_end = 1224
    _REQUESTSETOPTION._serialized_start = 1226
    _REQUESTSETOPTION._serialized_end = 1272
    _REQUESTINITCHAIN._serialized_start = 1275
    _REQUESTINITCHAIN._serialized_end = 1532
    _REQUESTQUERY._serialized_start = 1534
    _REQUESTQUERY._serialized_end = 1607
    _REQUESTBEGINBLOCK._serialized_start = 1610
    _REQUESTBEGINBLOCK._serialized_end = 1819
    _REQUESTCHECKTX._serialized_start = 1821
    _REQUESTCHECKTX._serialized_end = 1893
    _REQUESTDELIVERTX._serialized_start = 1895
    _REQUESTDELIVERTX._serialized_end = 1925
    _REQUESTENDBLOCK._serialized_start = 1927
    _REQUESTENDBLOCK._serialized_end = 1960
    _REQUESTCOMMIT._serialized_start = 1962
    _REQUESTCOMMIT._serialized_end = 1977
    _REQUESTLISTSNAPSHOTS._serialized_start = 1979
    _REQUESTLISTSNAPSHOTS._serialized_end = 2001
    _REQUESTOFFERSNAPSHOT._serialized_start = 2003
    _REQUESTOFFERSNAPSHOT._serialized_end = 2088
    _REQUESTLOADSNAPSHOTCHUNK._serialized_start = 2090
    _REQUESTLOADSNAPSHOTCHUNK._serialized_end = 2163
    _REQUESTAPPLYSNAPSHOTCHUNK._serialized_start = 2165
    _REQUESTAPPLYSNAPSHOTCHUNK._serialized_end = 2238
    _RESPONSE._serialized_start = 2241
    _RESPONSE._serialized_end = 3188
    _RESPONSEEXCEPTION._serialized_start = 3190
    _RESPONSEEXCEPTION._serialized_end = 3224
    _RESPONSEECHO._serialized_start = 3226
    _RESPONSEECHO._serialized_end = 3257
    _RESPONSEFLUSH._serialized_start = 3259
    _RESPONSEFLUSH._serialized_end = 3274
    _RESPONSEINFO._serialized_start = 3276
    _RESPONSEINFO._serialized_end = 3398
    _RESPONSESETOPTION._serialized_start = 3400
    _RESPONSESETOPTION._serialized_end = 3460
    _RESPONSEINITCHAIN._serialized_start = 3463
    _RESPONSEINITCHAIN._serialized_end = 3620
    _RESPONSEQUERY._serialized_start = 3623
    _RESPONSEQUERY._serialized_end = 3805
    _RESPONSEBEGINBLOCK._serialized_start = 3807
    _RESPONSEBEGINBLOCK._serialized_end = 3893
    _RESPONSECHECKTX._serialized_start = 3896
    _RESPONSECHECKTX._serialized_end = 4113
    _RESPONSEDELIVERTX._serialized_start = 4116
    _RESPONSEDELIVERTX._serialized_end = 4335
    _RESPONSEENDBLOCK._serialized_start = 4338
    _RESPONSEENDBLOCK._serialized_end = 4556
    _RESPONSECOMMIT._serialized_start = 4558
    _RESPONSECOMMIT._serialized_end = 4611
    _RESPONSELISTSNAPSHOTS._serialized_start = 4613
    _RESPONSELISTSNAPSHOTS._serialized_end = 4682
    _RESPONSEOFFERSNAPSHOT._serialized_start = 4685
    _RESPONSEOFFERSNAPSHOT._serialized_end = 4867
    _RESPONSEOFFERSNAPSHOT_RESULT._serialized_start = 4773
    _RESPONSEOFFERSNAPSHOT_RESULT._serialized_end = 4867
    _RESPONSELOADSNAPSHOTCHUNK._serialized_start = 4869
    _RESPONSELOADSNAPSHOTCHUNK._serialized_end = 4911
    _RESPONSEAPPLYSNAPSHOTCHUNK._serialized_start = 4914
    _RESPONSEAPPLYSNAPSHOTCHUNK._serialized_end = 5156
    _RESPONSEAPPLYSNAPSHOTCHUNK_RESULT._serialized_start = 5060
    _RESPONSEAPPLYSNAPSHOTCHUNK_RESULT._serialized_end = 5156
    _CONSENSUSPARAMS._serialized_start = 5159
    _CONSENSUSPARAMS._serialized_end = 5377
    _BLOCKPARAMS._serialized_start = 5379
    _BLOCKPARAMS._serialized_end = 5428
    _LASTCOMMITINFO._serialized_start = 5430
    _LASTCOMMITINFO._serialized_end = 5509
    _EVENT._serialized_start = 5511
    _EVENT._serialized_end = 5615
    _EVENTATTRIBUTE._serialized_start = 5617
    _EVENTATTRIBUTE._serialized_end = 5676
    _TXRESULT._serialized_start = 5678
    _TXRESULT._serialized_end = 5789
    _VALIDATOR._serialized_start = 5791
    _VALIDATOR._serialized_end = 5834
    _VALIDATORUPDATE._serialized_start = 5836
    _VALIDATORUPDATE._serialized_end = 5921
    _VOTEINFO._serialized_start = 5923
    _VOTEINFO._serialized_end = 6013
    _EVIDENCE._serialized_start = 6016
    _EVIDENCE._serialized_end = 6220
    _SNAPSHOT._serialized_start = 6222
    _SNAPSHOT._serialized_end = 6312
    _ABCIAPPLICATION._serialized_start = 6448
    _ABCIAPPLICATION._serialized_end = 7731




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/node/v2/events.proto\x12\x10sentinel.node.v2\x1a\x14gogoproto/gogo.proto\x1a\x1esentinel/types/v1/status.proto"4\n\rEventRegister\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address""9\n\x12EventUpdateDetails\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address""v\n\x11EventUpdateStatus\x12#\n\x07address\x18\x01 \x01(\tB\x12\xf2\xde\x1f\x0eyaml:"address"\x12<\n\x06status\x18\x02 \x01(\x0e2\x19.sentinel.types.v1.StatusB\x11\xf2\xde\x1f\ryaml:"status""i\n\x17EventCreateSubscription\x12\x1f\n\x02id\x18\x01 \x01(\x04B\x13\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"\x12-\n\x0cnode_address\x18\x02 \x01(\tB\x17\xf2\xde\x1f\x13yaml:"node_address"B7Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.node.v2.events_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/node/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _EVENTREGISTER.fields_by_name['address']._options = None
    _EVENTREGISTER.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTUPDATEDETAILS.fields_by_name['address']._options = None
    _EVENTUPDATEDETAILS.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTUPDATESTATUS.fields_by_name['address']._options = None
    _EVENTUPDATESTATUS.fields_by_name['address']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"address"'
    _EVENTUPDATESTATUS.fields_by_name['status']._options = None
    _EVENTUPDATESTATUS.fields_by_name['status']._serialized_options = b'\xf2\xde\x1f\ryaml:"status"'
    _EVENTCREATESUBSCRIPTION.fields_by_name['id']._options = None
    _EVENTCREATESUBSCRIPTION.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID\xf2\xde\x1f\tyaml:"id"'
    _EVENTCREATESUBSCRIPTION.fields_by_name['node_address']._options = None
    _EVENTCREATESUBSCRIPTION.fields_by_name['node_address']._serialized_options = b'\xf2\xde\x1f\x13yaml:"node_address"'
    _EVENTREGISTER._serialized_start = 105
    _EVENTREGISTER._serialized_end = 157
    _EVENTUPDATEDETAILS._serialized_start = 159
    _EVENTUPDATEDETAILS._serialized_end = 216
    _EVENTUPDATESTATUS._serialized_start = 218
    _EVENTUPDATESTATUS._serialized_end = 336
    _EVENTCREATESUBSCRIPTION._serialized_start = 338
    _EVENTCREATESUBSCRIPTION._serialized_end = 443




'Client and server classes corresponding to protobuf-defined services.'
import grpc
from .....interchain_security.ccv.consumer.v1 import query_pb2 as interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2

class QueryStub(object):
    'Missing associated documentation comment in .proto file.'

    def __init__(self, channel):
        'Constructor.\n\n        Args:\n            channel: A grpc.Channel.\n        '
        self.QueryNextFeeDistribution = channel.unary_unary('/interchain_security.ccv.consumer.v1.Query/QueryNextFeeDistribution', request_serializer=interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateRequest.SerializeToString, response_deserializer=interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateResponse.FromString)

class QueryServicer(object):
    'Missing associated documentation comment in .proto file.'

    def QueryNextFeeDistribution(self, request, context):
        'ConsumerGenesis queries the genesis state needed to start a consumer chain\n        whose proposal has been accepted\n        '
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {'QueryNextFeeDistribution': grpc.unary_unary_rpc_method_handler(servicer.QueryNextFeeDistribution, request_deserializer=interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateRequest.FromString, response_serializer=interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('interchain_security.ccv.consumer.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))

class Query(object):
    'Missing associated documentation comment in .proto file.'

    @staticmethod
    def QueryNextFeeDistribution(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/interchain_security.ccv.consumer.v1.Query/QueryNextFeeDistribution', interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateRequest.SerializeToString, interchain__security_dot_ccv_dot_consumer_dot_v1_dot_query__pb2.QueryNextFeeDistributionEstimateResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata)




from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class StoreKVPair(_message.Message):
    __slots__ = ['delete', 'key', 'store_key', 'value']
    DELETE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    STORE_KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    delete: bool
    key: bytes
    store_key: str
    value: bytes

    def __init__(self, store_key: _Optional[str]=..., delete: bool=..., key: _Optional[bytes]=..., value: _Optional[bytes]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)sentinel/subscription/v2/allocation.proto\x12\x18sentinel.subscription.v2\x1a\x14gogoproto/gogo.proto"\xc0\x01\n\nAllocation\x12\x12\n\x02id\x18\x01 \x01(\x04B\x06\xe2\xde\x1f\x02ID\x12\x0f\n\x07address\x18\x02 \x01(\t\x12E\n\rgranted_bytes\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12F\n\x0eutilised_bytes\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00B?Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v2.allocation_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z5github.com/sentinel-official/hub/x/subscription/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _ALLOCATION.fields_by_name['id']._options = None
    _ALLOCATION.fields_by_name['id']._serialized_options = b'\xe2\xde\x1f\x02ID'
    _ALLOCATION.fields_by_name['granted_bytes']._options = None
    _ALLOCATION.fields_by_name['granted_bytes']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _ALLOCATION.fields_by_name['utilised_bytes']._options = None
    _ALLOCATION.fields_by_name['utilised_bytes']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _ALLOCATION._serialized_start = 94
    _ALLOCATION._serialized_end = 286




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtendermint/types/params.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto"\xf3\x01\n\x0fConsensusParams\x122\n\x05block\x18\x01 \x01(\x0b2\x1d.tendermint.types.BlockParamsB\x04\xc8\xde\x1f\x00\x128\n\x08evidence\x18\x02 \x01(\x0b2 .tendermint.types.EvidenceParamsB\x04\xc8\xde\x1f\x00\x12:\n\tvalidator\x18\x03 \x01(\x0b2!.tendermint.types.ValidatorParamsB\x04\xc8\xde\x1f\x00\x126\n\x07version\x18\x04 \x01(\x0b2\x1f.tendermint.types.VersionParamsB\x04\xc8\xde\x1f\x00"G\n\x0bBlockParams\x12\x11\n\tmax_bytes\x18\x01 \x01(\x03\x12\x0f\n\x07max_gas\x18\x02 \x01(\x03\x12\x14\n\x0ctime_iota_ms\x18\x03 \x01(\x03"~\n\x0eEvidenceParams\x12\x1a\n\x12max_age_num_blocks\x18\x01 \x01(\x03\x12=\n\x10max_age_duration\x18\x02 \x01(\x0b2\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01\x12\x11\n\tmax_bytes\x18\x03 \x01(\x03"2\n\x0fValidatorParams\x12\x15\n\rpub_key_types\x18\x01 \x03(\t:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01".\n\rVersionParams\x12\x13\n\x0bapp_version\x18\x01 \x01(\x04:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01">\n\x0cHashedParams\x12\x17\n\x0fblock_max_bytes\x18\x01 \x01(\x03\x12\x15\n\rblock_max_gas\x18\x02 \x01(\x03B=Z7github.com/tendermint/tendermint/proto/tendermint/types\xa8\xe2\x1e\x01b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.params_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types\xa8\xe2\x1e\x01'
    _CONSENSUSPARAMS.fields_by_name['block']._options = None
    _CONSENSUSPARAMS.fields_by_name['block']._serialized_options = b'\xc8\xde\x1f\x00'
    _CONSENSUSPARAMS.fields_by_name['evidence']._options = None
    _CONSENSUSPARAMS.fields_by_name['evidence']._serialized_options = b'\xc8\xde\x1f\x00'
    _CONSENSUSPARAMS.fields_by_name['validator']._options = None
    _CONSENSUSPARAMS.fields_by_name['validator']._serialized_options = b'\xc8\xde\x1f\x00'
    _CONSENSUSPARAMS.fields_by_name['version']._options = None
    _CONSENSUSPARAMS.fields_by_name['version']._serialized_options = b'\xc8\xde\x1f\x00'
    _EVIDENCEPARAMS.fields_by_name['max_age_duration']._options = None
    _EVIDENCEPARAMS.fields_by_name['max_age_duration']._serialized_options = b'\xc8\xde\x1f\x00\x98\xdf\x1f\x01'
    _VALIDATORPARAMS._options = None
    _VALIDATORPARAMS._serialized_options = b'\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01'
    _VERSIONPARAMS._options = None
    _VERSIONPARAMS._serialized_options = b'\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01'
    _CONSENSUSPARAMS._serialized_start = 106
    _CONSENSUSPARAMS._serialized_end = 349
    _BLOCKPARAMS._serialized_start = 351
    _BLOCKPARAMS._serialized_end = 422
    _EVIDENCEPARAMS._serialized_start = 424
    _EVIDENCEPARAMS._serialized_end = 550
    _VALIDATORPARAMS._serialized_start = 552
    _VALIDATORPARAMS._serialized_end = 602
    _VERSIONPARAMS._serialized_start = 604
    _VERSIONPARAMS._serialized_end = 650
    _HASHEDPARAMS._serialized_start = 652
    _HASHEDPARAMS._serialized_end = 714




from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.types.v1 import status_pb2 as _status_pb2
from sentinel.node.v2 import node_pb2 as _node_pb2
from sentinel.node.v2 import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryNodeRequest(_message.Message):
    __slots__ = ['address']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str

    def __init__(self, address: _Optional[str]=...) -> None:
        ...

class QueryNodeResponse(_message.Message):
    __slots__ = ['node']
    NODE_FIELD_NUMBER: _ClassVar[int]
    node: _node_pb2.Node

    def __init__(self, node: _Optional[_Union[(_node_pb2.Node, _Mapping)]]=...) -> None:
        ...

class QueryNodesForPlanRequest(_message.Message):
    __slots__ = ['id', 'pagination', 'status']
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: int
    pagination: _pagination_pb2.PageRequest
    status: _status_pb2.Status

    def __init__(self, id: _Optional[int]=..., status: _Optional[_Union[(_status_pb2.Status, str)]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryNodesForPlanResponse(_message.Message):
    __slots__ = ['nodes', 'pagination']
    NODES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[_node_pb2.Node]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, nodes: _Optional[_Iterable[_Union[(_node_pb2.Node, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryNodesRequest(_message.Message):
    __slots__ = ['pagination', 'status']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    status: _status_pb2.Status

    def __init__(self, status: _Optional[_Union[(_status_pb2.Status, str)]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QueryNodesResponse(_message.Message):
    __slots__ = ['nodes', 'pagination']
    NODES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[_node_pb2.Node]
    pagination: _pagination_pb2.PageResponse

    def __init__(self, nodes: _Optional[_Iterable[_Union[(_node_pb2.Node, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QueryParamsRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryParamsResponse(_message.Message):
    __slots__ = ['params']
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params

    def __init__(self, params: _Optional[_Union[(_params_pb2.Params, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from tendermint.consensus import types_pb2 as _types_pb2
from tendermint.types import events_pb2 as _events_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class EndHeight(_message.Message):
    __slots__ = ['height']
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    height: int

    def __init__(self, height: _Optional[int]=...) -> None:
        ...

class MsgInfo(_message.Message):
    __slots__ = ['msg', 'peer_id']
    MSG_FIELD_NUMBER: _ClassVar[int]
    PEER_ID_FIELD_NUMBER: _ClassVar[int]
    msg: _types_pb2.Message
    peer_id: str

    def __init__(self, msg: _Optional[_Union[(_types_pb2.Message, _Mapping)]]=..., peer_id: _Optional[str]=...) -> None:
        ...

class TimedWALMessage(_message.Message):
    __slots__ = ['msg', 'time']
    MSG_FIELD_NUMBER: _ClassVar[int]
    TIME_FIELD_NUMBER: _ClassVar[int]
    msg: WALMessage
    time: _timestamp_pb2.Timestamp

    def __init__(self, time: _Optional[_Union[(_timestamp_pb2.Timestamp, _Mapping)]]=..., msg: _Optional[_Union[(WALMessage, _Mapping)]]=...) -> None:
        ...

class TimeoutInfo(_message.Message):
    __slots__ = ['duration', 'height', 'round', 'step']
    DURATION_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ROUND_FIELD_NUMBER: _ClassVar[int]
    STEP_FIELD_NUMBER: _ClassVar[int]
    duration: _duration_pb2.Duration
    height: int
    round: int
    step: int

    def __init__(self, duration: _Optional[_Union[(_duration_pb2.Duration, _Mapping)]]=..., height: _Optional[int]=..., round: _Optional[int]=..., step: _Optional[int]=...) -> None:
        ...

class WALMessage(_message.Message):
    __slots__ = ['end_height', 'event_data_round_state', 'msg_info', 'timeout_info']
    END_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    EVENT_DATA_ROUND_STATE_FIELD_NUMBER: _ClassVar[int]
    MSG_INFO_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_INFO_FIELD_NUMBER: _ClassVar[int]
    end_height: EndHeight
    event_data_round_state: _events_pb2.EventDataRoundState
    msg_info: MsgInfo
    timeout_info: TimeoutInfo

    def __init__(self, event_data_round_state: _Optional[_Union[(_events_pb2.EventDataRoundState, _Mapping)]]=..., msg_info: _Optional[_Union[(MsgInfo, _Mapping)]]=..., timeout_info: _Optional[_Union[(TimeoutInfo, _Mapping)]]=..., end_height: _Optional[_Union[(EndHeight, _Mapping)]]=...) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ....cosmos.base.abci.v1beta1 import abci_pb2 as cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2
from ....cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dcosmos/authz/v1beta1/tx.proto\x12\x14cosmos.authz.v1beta1\x1a\x19cosmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a#cosmos/base/abci/v1beta1/abci.proto\x1a cosmos/authz/v1beta1/authz.proto"^\n\x08MsgGrant\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x120\n\x05grant\x18\x03 \x01(\x0b2\x1b.cosmos.authz.v1beta1.GrantB\x04\xc8\xde\x1f\x00""\n\x0fMsgExecResponse\x12\x0f\n\x07results\x18\x01 \x03(\x0c"`\n\x07MsgExec\x12\x0f\n\x07grantee\x18\x01 \x01(\t\x12D\n\x04msgs\x18\x02 \x03(\x0b2\x14.google.protobuf.AnyB \xca\xb4-\x1csdk.Msg, authz.Authorization"\x12\n\x10MsgGrantResponse"C\n\tMsgRevoke\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x14\n\x0cmsg_type_url\x18\x03 \x01(\t"\x13\n\x11MsgRevokeResponse2\xf8\x01\n\x03Msg\x12O\n\x05Grant\x12\x1e.cosmos.authz.v1beta1.MsgGrant\x1a&.cosmos.authz.v1beta1.MsgGrantResponse\x12L\n\x04Exec\x12\x1d.cosmos.authz.v1beta1.MsgExec\x1a%.cosmos.authz.v1beta1.MsgExecResponse\x12R\n\x06Revoke\x12\x1f.cosmos.authz.v1beta1.MsgRevoke\x1a\'.cosmos.authz.v1beta1.MsgRevokeResponseB*Z$github.com/cosmos/cosmos-sdk/x/authz\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.authz.v1beta1.tx_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz\xc8\xe1\x1e\x00'
    _MSGGRANT.fields_by_name['grant']._options = None
    _MSGGRANT.fields_by_name['grant']._serialized_options = b'\xc8\xde\x1f\x00'
    _MSGEXEC.fields_by_name['msgs']._options = None
    _MSGEXEC.fields_by_name['msgs']._serialized_options = b'\xca\xb4-\x1csdk.Msg, authz.Authorization'
    _MSGGRANT._serialized_start = 235
    _MSGGRANT._serialized_end = 329
    _MSGEXECRESPONSE._serialized_start = 331
    _MSGEXECRESPONSE._serialized_end = 365
    _MSGEXEC._serialized_start = 367
    _MSGEXEC._serialized_end = 463
    _MSGGRANTRESPONSE._serialized_start = 465
    _MSGGRANTRESPONSE._serialized_end = 483
    _MSGREVOKE._serialized_start = 485
    _MSGREVOKE._serialized_end = 552
    _MSGREVOKERESPONSE._serialized_start = 554
    _MSGREVOKERESPONSE._serialized_end = 573
    _MSG._serialized_start = 576
    _MSG._serialized_end = 824




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dsentinel/swap/v1/events.proto\x12\x10sentinel.swap.v1\x1a\x14gogoproto/gogo.proto"W\n\tEventSwap\x12#\n\x07tx_hash\x18\x01 \x01(\x0cB\x12\xf2\xde\x1f\x0eyaml:"tx_hash"\x12%\n\x08receiver\x18\x02 \x01(\tB\x13\xf2\xde\x1f\x0fyaml:"receiver"B7Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.swap.v1.events_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _EVENTSWAP.fields_by_name['tx_hash']._options = None
    _EVENTSWAP.fields_by_name['tx_hash']._serialized_options = b'\xf2\xde\x1f\x0eyaml:"tx_hash"'
    _EVENTSWAP.fields_by_name['receiver']._options = None
    _EVENTSWAP.fields_by_name['receiver']._serialized_options = b'\xf2\xde\x1f\x0fyaml:"receiver"'
    _EVENTSWAP._serialized_start = 73
    _EVENTSWAP._serialized_end = 160




from tendermint.abci import types_pb2 as _types_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class RequestBroadcastTx(_message.Message):
    __slots__ = ['tx']
    TX_FIELD_NUMBER: _ClassVar[int]
    tx: bytes

    def __init__(self, tx: _Optional[bytes]=...) -> None:
        ...

class RequestPing(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class ResponseBroadcastTx(_message.Message):
    __slots__ = ['check_tx', 'deliver_tx']
    CHECK_TX_FIELD_NUMBER: _ClassVar[int]
    DELIVER_TX_FIELD_NUMBER: _ClassVar[int]
    check_tx: _types_pb2.ResponseCheckTx
    deliver_tx: _types_pb2.ResponseDeliverTx

    def __init__(self, check_tx: _Optional[_Union[(_types_pb2.ResponseCheckTx, _Mapping)]]=..., deliver_tx: _Optional[_Union[(_types_pb2.ResponseDeliverTx, _Mapping)]]=...) -> None:
        ...

class ResponsePing(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ....sentinel.types.v1 import status_pb2 as sentinel_dot_types_dot_v1_dot_status__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+sentinel/subscription/v1/subscription.proto\x12\x18sentinel.subscription.v1\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1esentinel/types/v1/status.proto"\x8e\x03\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\x04\x12\r\n\x05owner\x18\x02 \x01(\t\x12\x0c\n\x04node\x18\x03 \x01(\t\x12.\n\x05price\x18\x04 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x120\n\x07deposit\x18\x05 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x0c\n\x04plan\x18\x06 \x01(\x04\x12\r\n\x05denom\x18\x07 \x01(\t\x124\n\x06expiry\x18\x08 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12<\n\x04free\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12)\n\x06status\x18\n \x01(\x0e2\x19.sentinel.types.v1.Status\x127\n\tstatus_at\x18\x0b \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01BIZ?github.com/sentinel-official/hub/x/subscription/legacy/v1/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.subscription.v1.subscription_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z?github.com/sentinel-official/hub/x/subscription/legacy/v1/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _SUBSCRIPTION.fields_by_name['price']._options = None
    _SUBSCRIPTION.fields_by_name['price']._serialized_options = b'\xc8\xde\x1f\x00'
    _SUBSCRIPTION.fields_by_name['deposit']._options = None
    _SUBSCRIPTION.fields_by_name['deposit']._serialized_options = b'\xc8\xde\x1f\x00'
    _SUBSCRIPTION.fields_by_name['expiry']._options = None
    _SUBSCRIPTION.fields_by_name['expiry']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _SUBSCRIPTION.fields_by_name['free']._options = None
    _SUBSCRIPTION.fields_by_name['free']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _SUBSCRIPTION.fields_by_name['status_at']._options = None
    _SUBSCRIPTION.fields_by_name['status_at']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _SUBSCRIPTION._serialized_start = 193
    _SUBSCRIPTION._serialized_end = 591




from gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional
DESCRIPTOR: _descriptor.FileDescriptor

class MsgVerifyInvariant(_message.Message):
    __slots__ = ['invariant_module_name', 'invariant_route', 'sender']
    INVARIANT_MODULE_NAME_FIELD_NUMBER: _ClassVar[int]
    INVARIANT_ROUTE_FIELD_NUMBER: _ClassVar[int]
    SENDER_FIELD_NUMBER: _ClassVar[int]
    invariant_module_name: str
    invariant_route: str
    sender: str

    def __init__(self, sender: _Optional[str]=..., invariant_module_name: _Optional[str]=..., invariant_route: _Optional[str]=...) -> None:
        ...

class MsgVerifyInvariantResponse(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from ....cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ccosmos/gov/v1beta1/gov.proto\x12\x12cosmos.gov.v1beta1\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x19cosmos_proto/cosmos.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto"\x95\x01\n\x12WeightedVoteOption\x12.\n\x06option\x18\x01 \x01(\x0e2\x1e.cosmos.gov.v1beta1.VoteOption\x12O\n\x06weight\x18\x02 \x01(\tB?\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xf2\xde\x1f\ryaml:"weight""C\n\x0cTextProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t:\x0f\xca\xb4-\x07Content\xe8\xa0\x1f\x01"\xb0\x01\n\x07Deposit\x12+\n\x0bproposal_id\x18\x01 \x01(\x04B\x16\xf2\xde\x1f\x12yaml:"proposal_id"\x12\x11\n\tdepositor\x18\x02 \x01(\t\x12[\n\x06amount\x18\x03 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00"\xfc\x05\n\x08Proposal\x12(\n\x0bproposal_id\x18\x01 \x01(\x04B\x13\xea\xde\x1f\x02id\xf2\xde\x1f\tyaml:"id"\x122\n\x07content\x18\x02 \x01(\x0b2\x14.google.protobuf.AnyB\x0b\xca\xb4-\x07Content\x12N\n\x06status\x18\x03 \x01(\x0e2".cosmos.gov.v1beta1.ProposalStatusB\x1a\xf2\xde\x1f\x16yaml:"proposal_status"\x12^\n\x12final_tally_result\x18\x04 \x01(\x0b2\x1f.cosmos.gov.v1beta1.TallyResultB!\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:"final_tally_result"\x12O\n\x0bsubmit_time\x18\x05 \x01(\x0b2\x1a.google.protobuf.TimestampB\x1e\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x12yaml:"submit_time"\x12Y\n\x10deposit_end_time\x18\x06 \x01(\x0b2\x1a.google.protobuf.TimestampB#\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x17yaml:"deposit_end_time"\x12z\n\rtotal_deposit\x18\x07 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinBH\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x14yaml:"total_deposit"\x12[\n\x11voting_start_time\x18\x08 \x01(\x0b2\x1a.google.protobuf.TimestampB$\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x18yaml:"voting_start_time"\x12W\n\x0fvoting_end_time\x18\t \x01(\x0b2\x1a.google.protobuf.TimestampB"\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"voting_end_time":\x04\xe8\xa0\x1f\x01"\xaa\x02\n\x0bTallyResult\x12;\n\x03yes\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12?\n\x07abstain\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12:\n\x02no\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12[\n\x0cno_with_veto\x18\x04 \x01(\tBE\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:"no_with_veto":\x04\xe8\xa0\x1f\x01"\xbf\x01\n\x04Vote\x12+\n\x0bproposal_id\x18\x01 \x01(\x04B\x16\xf2\xde\x1f\x12yaml:"proposal_id"\x12\r\n\x05voter\x18\x02 \x01(\t\x122\n\x06option\x18\x03 \x01(\x0e2\x1e.cosmos.gov.v1beta1.VoteOptionB\x02\x18\x01\x12=\n\x07options\x18\x04 \x03(\x0b2&.cosmos.gov.v1beta1.WeightedVoteOptionB\x04\xc8\xde\x1f\x00:\x08\x98\xa0\x1f\x00\xe8\xa0\x1f\x00"\x9f\x02\n\rDepositParams\x12\x8f\x01\n\x0bmin_deposit\x18\x01 \x03(\x0b2\x19.cosmos.base.v1beta1.CoinB_\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x12yaml:"min_deposit"\xea\xde\x1f\x15min_deposit,omitempty\x12|\n\x12max_deposit_period\x18\x02 \x01(\x0b2\x19.google.protobuf.DurationBE\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x1cmax_deposit_period,omitempty\xf2\xde\x1f\x19yaml:"max_deposit_period""}\n\x0cVotingParams\x12m\n\rvoting_period\x18\x01 \x01(\x0b2\x19.google.protobuf.DurationB;\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x17voting_period,omitempty\xf2\xde\x1f\x14yaml:"voting_period""\xb8\x02\n\x0bTallyParams\x12R\n\x06quorum\x18\x01 \x01(\x0cBB\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xea\xde\x1f\x10quorum,omitempty\x12X\n\tthreshold\x18\x02 \x01(\x0cBE\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xea\xde\x1f\x13threshold,omitempty\x12{\n\x0eveto_threshold\x18\x03 \x01(\x0cBc\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xea\xde\x1f\x18veto_threshold,omitempty\xf2\xde\x1f\x15yaml:"veto_threshold"*\xe6\x01\n\nVoteOption\x12,\n\x17VOTE_OPTION_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bOptionEmpty\x12"\n\x0fVOTE_OPTION_YES\x10\x01\x1a\r\x8a\x9d \tOptionYes\x12*\n\x13VOTE_OPTION_ABSTAIN\x10\x02\x1a\x11\x8a\x9d \rOptionAbstain\x12 \n\x0eVOTE_OPTION_NO\x10\x03\x1a\x0c\x8a\x9d \x08OptionNo\x122\n\x18VOTE_OPTION_NO_WITH_VETO\x10\x04\x1a\x14\x8a\x9d \x10OptionNoWithVeto\x1a\x04\x88\xa3\x1e\x00*\xcc\x02\n\x0eProposalStatus\x12.\n\x1bPROPOSAL_STATUS_UNSPECIFIED\x10\x00\x1a\r\x8a\x9d \tStatusNil\x12;\n\x1ePROPOSAL_STATUS_DEPOSIT_PERIOD\x10\x01\x1a\x17\x8a\x9d \x13StatusDepositPeriod\x129\n\x1dPROPOSAL_STATUS_VOTING_PERIOD\x10\x02\x1a\x16\x8a\x9d \x12StatusVotingPeriod\x12,\n\x16PROPOSAL_STATUS_PASSED\x10\x03\x1a\x10\x8a\x9d \x0cStatusPassed\x120\n\x18PROPOSAL_STATUS_REJECTED\x10\x04\x1a\x12\x8a\x9d \x0eStatusRejected\x12,\n\x16PROPOSAL_STATUS_FAILED\x10\x05\x1a\x10\x8a\x9d \x0cStatusFailed\x1a\x04\x88\xa3\x1e\x00B6Z(github.com/cosmos/cosmos-sdk/x/gov/types\xd8\xe1\x1e\x00\x80\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1beta1.gov_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z(github.com/cosmos/cosmos-sdk/x/gov/types\xd8\xe1\x1e\x00\x80\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _VOTEOPTION._options = None
    _VOTEOPTION._serialized_options = b'\x88\xa3\x1e\x00'
    _VOTEOPTION.values_by_name['VOTE_OPTION_UNSPECIFIED']._options = None
    _VOTEOPTION.values_by_name['VOTE_OPTION_UNSPECIFIED']._serialized_options = b'\x8a\x9d \x0bOptionEmpty'
    _VOTEOPTION.values_by_name['VOTE_OPTION_YES']._options = None
    _VOTEOPTION.values_by_name['VOTE_OPTION_YES']._serialized_options = b'\x8a\x9d \tOptionYes'
    _VOTEOPTION.values_by_name['VOTE_OPTION_ABSTAIN']._options = None
    _VOTEOPTION.values_by_name['VOTE_OPTION_ABSTAIN']._serialized_options = b'\x8a\x9d \rOptionAbstain'
    _VOTEOPTION.values_by_name['VOTE_OPTION_NO']._options = None
    _VOTEOPTION.values_by_name['VOTE_OPTION_NO']._serialized_options = b'\x8a\x9d \x08OptionNo'
    _VOTEOPTION.values_by_name['VOTE_OPTION_NO_WITH_VETO']._options = None
    _VOTEOPTION.values_by_name['VOTE_OPTION_NO_WITH_VETO']._serialized_options = b'\x8a\x9d \x10OptionNoWithVeto'
    _PROPOSALSTATUS._options = None
    _PROPOSALSTATUS._serialized_options = b'\x88\xa3\x1e\x00'
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_UNSPECIFIED']._options = None
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_UNSPECIFIED']._serialized_options = b'\x8a\x9d \tStatusNil'
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_DEPOSIT_PERIOD']._options = None
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_DEPOSIT_PERIOD']._serialized_options = b'\x8a\x9d \x13StatusDepositPeriod'
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_VOTING_PERIOD']._options = None
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_VOTING_PERIOD']._serialized_options = b'\x8a\x9d \x12StatusVotingPeriod'
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_PASSED']._options = None
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_PASSED']._serialized_options = b'\x8a\x9d \x0cStatusPassed'
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_REJECTED']._options = None
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_REJECTED']._serialized_options = b'\x8a\x9d \x0eStatusRejected'
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_FAILED']._options = None
    _PROPOSALSTATUS.values_by_name['PROPOSAL_STATUS_FAILED']._serialized_options = b'\x8a\x9d \x0cStatusFailed'
    _WEIGHTEDVOTEOPTION.fields_by_name['weight']._options = None
    _WEIGHTEDVOTEOPTION.fields_by_name['weight']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xf2\xde\x1f\ryaml:"weight"'
    _TEXTPROPOSAL._options = None
    _TEXTPROPOSAL._serialized_options = b'\xca\xb4-\x07Content\xe8\xa0\x1f\x01'
    _DEPOSIT.fields_by_name['proposal_id']._options = None
    _DEPOSIT.fields_by_name['proposal_id']._serialized_options = b'\xf2\xde\x1f\x12yaml:"proposal_id"'
    _DEPOSIT.fields_by_name['amount']._options = None
    _DEPOSIT.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins'
    _DEPOSIT._options = None
    _DEPOSIT._serialized_options = b'\x88\xa0\x1f\x00\xe8\xa0\x1f\x00'
    _PROPOSAL.fields_by_name['proposal_id']._options = None
    _PROPOSAL.fields_by_name['proposal_id']._serialized_options = b'\xea\xde\x1f\x02id\xf2\xde\x1f\tyaml:"id"'
    _PROPOSAL.fields_by_name['content']._options = None
    _PROPOSAL.fields_by_name['content']._serialized_options = b'\xca\xb4-\x07Content'
    _PROPOSAL.fields_by_name['status']._options = None
    _PROPOSAL.fields_by_name['status']._serialized_options = b'\xf2\xde\x1f\x16yaml:"proposal_status"'
    _PROPOSAL.fields_by_name['final_tally_result']._options = None
    _PROPOSAL.fields_by_name['final_tally_result']._serialized_options = b'\xc8\xde\x1f\x00\xf2\xde\x1f\x19yaml:"final_tally_result"'
    _PROPOSAL.fields_by_name['submit_time']._options = None
    _PROPOSAL.fields_by_name['submit_time']._serialized_options = b'\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x12yaml:"submit_time"'
    _PROPOSAL.fields_by_name['deposit_end_time']._options = None
    _PROPOSAL.fields_by_name['deposit_end_time']._serialized_options = b'\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x17yaml:"deposit_end_time"'
    _PROPOSAL.fields_by_name['total_deposit']._options = None
    _PROPOSAL.fields_by_name['total_deposit']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x14yaml:"total_deposit"'
    _PROPOSAL.fields_by_name['voting_start_time']._options = None
    _PROPOSAL.fields_by_name['voting_start_time']._serialized_options = b'\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x18yaml:"voting_start_time"'
    _PROPOSAL.fields_by_name['voting_end_time']._options = None
    _PROPOSAL.fields_by_name['voting_end_time']._serialized_options = b'\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:"voting_end_time"'
    _PROPOSAL._options = None
    _PROPOSAL._serialized_options = b'\xe8\xa0\x1f\x01'
    _TALLYRESULT.fields_by_name['yes']._options = None
    _TALLYRESULT.fields_by_name['yes']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _TALLYRESULT.fields_by_name['abstain']._options = None
    _TALLYRESULT.fields_by_name['abstain']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _TALLYRESULT.fields_by_name['no']._options = None
    _TALLYRESULT.fields_by_name['no']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00'
    _TALLYRESULT.fields_by_name['no_with_veto']._options = None
    _TALLYRESULT.fields_by_name['no_with_veto']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:"no_with_veto"'
    _TALLYRESULT._options = None
    _TALLYRESULT._serialized_options = b'\xe8\xa0\x1f\x01'
    _VOTE.fields_by_name['proposal_id']._options = None
    _VOTE.fields_by_name['proposal_id']._serialized_options = b'\xf2\xde\x1f\x12yaml:"proposal_id"'
    _VOTE.fields_by_name['option']._options = None
    _VOTE.fields_by_name['option']._serialized_options = b'\x18\x01'
    _VOTE.fields_by_name['options']._options = None
    _VOTE.fields_by_name['options']._serialized_options = b'\xc8\xde\x1f\x00'
    _VOTE._options = None
    _VOTE._serialized_options = b'\x98\xa0\x1f\x00\xe8\xa0\x1f\x00'
    _DEPOSITPARAMS.fields_by_name['min_deposit']._options = None
    _DEPOSITPARAMS.fields_by_name['min_deposit']._serialized_options = b'\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x12yaml:"min_deposit"\xea\xde\x1f\x15min_deposit,omitempty'
    _DEPOSITPARAMS.fields_by_name['max_deposit_period']._options = None
    _DEPOSITPARAMS.fields_by_name['max_deposit_period']._serialized_options = b'\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x1cmax_deposit_period,omitempty\xf2\xde\x1f\x19yaml:"max_deposit_period"'
    _VOTINGPARAMS.fields_by_name['voting_period']._options = None
    _VOTINGPARAMS.fields_by_name['voting_period']._serialized_options = b'\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x17voting_period,omitempty\xf2\xde\x1f\x14yaml:"voting_period"'
    _TALLYPARAMS.fields_by_name['quorum']._options = None
    _TALLYPARAMS.fields_by_name['quorum']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xea\xde\x1f\x10quorum,omitempty'
    _TALLYPARAMS.fields_by_name['threshold']._options = None
    _TALLYPARAMS.fields_by_name['threshold']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xea\xde\x1f\x13threshold,omitempty'
    _TALLYPARAMS.fields_by_name['veto_threshold']._options = None
    _TALLYPARAMS.fields_by_name['veto_threshold']._serialized_options = b'\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\xea\xde\x1f\x18veto_threshold,omitempty\xf2\xde\x1f\x15yaml:"veto_threshold"'
    _VOTEOPTION._serialized_start = 2620
    _VOTEOPTION._serialized_end = 2850
    _PROPOSALSTATUS._serialized_start = 2853
    _PROPOSALSTATUS._serialized_end = 3185
    _WEIGHTEDVOTEOPTION._serialized_start = 226
    _WEIGHTEDVOTEOPTION._serialized_end = 375
    _TEXTPROPOSAL._serialized_start = 377
    _TEXTPROPOSAL._serialized_end = 444
    _DEPOSIT._serialized_start = 447
    _DEPOSIT._serialized_end = 623
    _PROPOSAL._serialized_start = 626
    _PROPOSAL._serialized_end = 1390
    _TALLYRESULT._serialized_start = 1393
    _TALLYRESULT._serialized_end = 1691
    _VOTE._serialized_start = 1694
    _VOTE._serialized_end = 1885
    _DEPOSITPARAMS._serialized_start = 1888
    _DEPOSITPARAMS._serialized_end = 2175
    _VOTINGPARAMS._serialized_start = 2177
    _VOTINGPARAMS._serialized_end = 2302
    _TALLYPARAMS._serialized_start = 2305
    _TALLYPARAMS._serialized_end = 2617




from cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from gogoproto import gogo_pb2 as _gogo_pb2
from google.api import annotations_pb2 as _annotations_pb2
from sentinel.session.v2 import params_pb2 as _params_pb2
from sentinel.session.v2 import session_pb2 as _session_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = []

    def __init__(self) -> None:
        ...

class QueryParamsResponse(_message.Message):
    __slots__ = ['params']
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params

    def __init__(self, params: _Optional[_Union[(_params_pb2.Params, _Mapping)]]=...) -> None:
        ...

class QuerySessionRequest(_message.Message):
    __slots__ = ['id']
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int

    def __init__(self, id: _Optional[int]=...) -> None:
        ...

class QuerySessionResponse(_message.Message):
    __slots__ = ['session']
    SESSION_FIELD_NUMBER: _ClassVar[int]
    session: _session_pb2.Session

    def __init__(self, session: _Optional[_Union[(_session_pb2.Session, _Mapping)]]=...) -> None:
        ...

class QuerySessionsForAccountRequest(_message.Message):
    __slots__ = ['address', 'pagination']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, address: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QuerySessionsForAccountResponse(_message.Message):
    __slots__ = ['pagination', 'sessions']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]

    def __init__(self, sessions: _Optional[_Iterable[_Union[(_session_pb2.Session, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QuerySessionsForAllocationRequest(_message.Message):
    __slots__ = ['address', 'id', 'pagination']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    id: int
    pagination: _pagination_pb2.PageRequest

    def __init__(self, id: _Optional[int]=..., address: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QuerySessionsForAllocationResponse(_message.Message):
    __slots__ = ['pagination', 'sessions']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]

    def __init__(self, sessions: _Optional[_Iterable[_Union[(_session_pb2.Session, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QuerySessionsForNodeRequest(_message.Message):
    __slots__ = ['address', 'pagination']
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest

    def __init__(self, address: _Optional[str]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QuerySessionsForNodeResponse(_message.Message):
    __slots__ = ['pagination', 'sessions']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]

    def __init__(self, sessions: _Optional[_Iterable[_Union[(_session_pb2.Session, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QuerySessionsForSubscriptionRequest(_message.Message):
    __slots__ = ['id', 'pagination']
    ID_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    id: int
    pagination: _pagination_pb2.PageRequest

    def __init__(self, id: _Optional[int]=..., pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QuerySessionsForSubscriptionResponse(_message.Message):
    __slots__ = ['pagination', 'sessions']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]

    def __init__(self, sessions: _Optional[_Iterable[_Union[(_session_pb2.Session, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...

class QuerySessionsRequest(_message.Message):
    __slots__ = ['pagination']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest

    def __init__(self, pagination: _Optional[_Union[(_pagination_pb2.PageRequest, _Mapping)]]=...) -> None:
        ...

class QuerySessionsResponse(_message.Message):
    __slots__ = ['pagination', 'sessions']
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    SESSIONS_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageResponse
    sessions: _containers.RepeatedCompositeFieldContainer[_session_pb2.Session]

    def __init__(self, sessions: _Optional[_Iterable[_Union[(_session_pb2.Session, _Mapping)]]]=..., pagination: _Optional[_Union[(_pagination_pb2.PageResponse, _Mapping)]]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.applications.interchain_accounts.controller.v1 import controller_pb2 as _controller_pb2
from ibc.applications.interchain_accounts.host.v1 import host_pb2 as _host_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor

class ActiveChannel(_message.Message):
    __slots__ = ['channel_id', 'connection_id', 'port_id']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    connection_id: str
    port_id: str

    def __init__(self, connection_id: _Optional[str]=..., port_id: _Optional[str]=..., channel_id: _Optional[str]=...) -> None:
        ...

class ControllerGenesisState(_message.Message):
    __slots__ = ['active_channels', 'interchain_accounts', 'params', 'ports']
    ACTIVE_CHANNELS_FIELD_NUMBER: _ClassVar[int]
    INTERCHAIN_ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    PORTS_FIELD_NUMBER: _ClassVar[int]
    active_channels: _containers.RepeatedCompositeFieldContainer[ActiveChannel]
    interchain_accounts: _containers.RepeatedCompositeFieldContainer[RegisteredInterchainAccount]
    params: _controller_pb2.Params
    ports: _containers.RepeatedScalarFieldContainer[str]

    def __init__(self, active_channels: _Optional[_Iterable[_Union[(ActiveChannel, _Mapping)]]]=..., interchain_accounts: _Optional[_Iterable[_Union[(RegisteredInterchainAccount, _Mapping)]]]=..., ports: _Optional[_Iterable[str]]=..., params: _Optional[_Union[(_controller_pb2.Params, _Mapping)]]=...) -> None:
        ...

class GenesisState(_message.Message):
    __slots__ = ['controller_genesis_state', 'host_genesis_state']
    CONTROLLER_GENESIS_STATE_FIELD_NUMBER: _ClassVar[int]
    HOST_GENESIS_STATE_FIELD_NUMBER: _ClassVar[int]
    controller_genesis_state: ControllerGenesisState
    host_genesis_state: HostGenesisState

    def __init__(self, controller_genesis_state: _Optional[_Union[(ControllerGenesisState, _Mapping)]]=..., host_genesis_state: _Optional[_Union[(HostGenesisState, _Mapping)]]=...) -> None:
        ...

class HostGenesisState(_message.Message):
    __slots__ = ['active_channels', 'interchain_accounts', 'params', 'port']
    ACTIVE_CHANNELS_FIELD_NUMBER: _ClassVar[int]
    INTERCHAIN_ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    active_channels: _containers.RepeatedCompositeFieldContainer[ActiveChannel]
    interchain_accounts: _containers.RepeatedCompositeFieldContainer[RegisteredInterchainAccount]
    params: _host_pb2.Params
    port: str

    def __init__(self, active_channels: _Optional[_Iterable[_Union[(ActiveChannel, _Mapping)]]]=..., interchain_accounts: _Optional[_Iterable[_Union[(RegisteredInterchainAccount, _Mapping)]]]=..., port: _Optional[str]=..., params: _Optional[_Union[(_host_pb2.Params, _Mapping)]]=...) -> None:
        ...

class RegisteredInterchainAccount(_message.Message):
    __slots__ = ['account_address', 'connection_id', 'port_id']
    ACCOUNT_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    account_address: str
    connection_id: str
    port_id: str

    def __init__(self, connection_id: _Optional[str]=..., port_id: _Optional[str]=..., account_address: _Optional[str]=...) -> None:
        ...




from gogoproto import gogo_pb2 as _gogo_pb2
from ibc.core.client.v1 import client_pb2 as _client_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union
DESCRIPTOR: _descriptor.FileDescriptor
ORDER_NONE_UNSPECIFIED: Order
ORDER_ORDERED: Order
ORDER_UNORDERED: Order
STATE_CLOSED: State
STATE_INIT: State
STATE_OPEN: State
STATE_TRYOPEN: State
STATE_UNINITIALIZED_UNSPECIFIED: State

class Acknowledgement(_message.Message):
    __slots__ = ['error', 'result']
    ERROR_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    error: str
    result: bytes

    def __init__(self, result: _Optional[bytes]=..., error: _Optional[str]=...) -> None:
        ...

class Channel(_message.Message):
    __slots__ = ['connection_hops', 'counterparty', 'ordering', 'state', 'version']
    CONNECTION_HOPS_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    ORDERING_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    connection_hops: _containers.RepeatedScalarFieldContainer[str]
    counterparty: Counterparty
    ordering: Order
    state: State
    version: str

    def __init__(self, state: _Optional[_Union[(State, str)]]=..., ordering: _Optional[_Union[(Order, str)]]=..., counterparty: _Optional[_Union[(Counterparty, _Mapping)]]=..., connection_hops: _Optional[_Iterable[str]]=..., version: _Optional[str]=...) -> None:
        ...

class Counterparty(_message.Message):
    __slots__ = ['channel_id', 'port_id']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    port_id: str

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=...) -> None:
        ...

class IdentifiedChannel(_message.Message):
    __slots__ = ['channel_id', 'connection_hops', 'counterparty', 'ordering', 'port_id', 'state', 'version']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_HOPS_FIELD_NUMBER: _ClassVar[int]
    COUNTERPARTY_FIELD_NUMBER: _ClassVar[int]
    ORDERING_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    connection_hops: _containers.RepeatedScalarFieldContainer[str]
    counterparty: Counterparty
    ordering: Order
    port_id: str
    state: State
    version: str

    def __init__(self, state: _Optional[_Union[(State, str)]]=..., ordering: _Optional[_Union[(Order, str)]]=..., counterparty: _Optional[_Union[(Counterparty, _Mapping)]]=..., connection_hops: _Optional[_Iterable[str]]=..., version: _Optional[str]=..., port_id: _Optional[str]=..., channel_id: _Optional[str]=...) -> None:
        ...

class Packet(_message.Message):
    __slots__ = ['data', 'destination_channel', 'destination_port', 'sequence', 'source_channel', 'source_port', 'timeout_height', 'timeout_timestamp']
    DATA_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_PORT_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_CHANNEL_FIELD_NUMBER: _ClassVar[int]
    SOURCE_PORT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    destination_channel: str
    destination_port: str
    sequence: int
    source_channel: str
    source_port: str
    timeout_height: _client_pb2.Height
    timeout_timestamp: int

    def __init__(self, sequence: _Optional[int]=..., source_port: _Optional[str]=..., source_channel: _Optional[str]=..., destination_port: _Optional[str]=..., destination_channel: _Optional[str]=..., data: _Optional[bytes]=..., timeout_height: _Optional[_Union[(_client_pb2.Height, _Mapping)]]=..., timeout_timestamp: _Optional[int]=...) -> None:
        ...

class PacketState(_message.Message):
    __slots__ = ['channel_id', 'data', 'port_id', 'sequence']
    CHANNEL_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    PORT_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    channel_id: str
    data: bytes
    port_id: str
    sequence: int

    def __init__(self, port_id: _Optional[str]=..., channel_id: _Optional[str]=..., sequence: _Optional[int]=..., data: _Optional[bytes]=...) -> None:
        ...

class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []

class Order(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bsentinel/swap/v1/swap.proto\x12\x10sentinel.swap.v1\x1a\x1ecosmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto"Z\n\x04Swap\x12\x0f\n\x07tx_hash\x18\x01 \x01(\x0c\x12\x10\n\x08receiver\x18\x02 \x01(\t\x12/\n\x06amount\x18\x03 \x01(\x0b2\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00B7Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sentinel.swap.v1.swap_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z-github.com/sentinel-official/hub/x/swap/types\xa8\xe2\x1e\x00\xc8\xe1\x1e\x00'
    _SWAP.fields_by_name['amount']._options = None
    _SWAP.fields_by_name['amount']._serialized_options = b'\xc8\xde\x1f\x00'
    _SWAP._serialized_start = 103
    _SWAP._serialized_end = 193




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ...gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...tendermint.crypto import proof_pb2 as tendermint_dot_crypto_dot_proof__pb2
from ...tendermint.version import types_pb2 as tendermint_dot_version_dot_types__pb2
from ...tendermint.types import validator_pb2 as tendermint_dot_types_dot_validator__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ctendermint/types/types.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dtendermint/crypto/proof.proto\x1a\x1etendermint/version/types.proto\x1a tendermint/types/validator.proto",\n\rPartSetHeader\x12\r\n\x05total\x18\x01 \x01(\r\x12\x0c\n\x04hash\x18\x02 \x01(\x0c"S\n\x04Part\x12\r\n\x05index\x18\x01 \x01(\r\x12\r\n\x05bytes\x18\x02 \x01(\x0c\x12-\n\x05proof\x18\x03 \x01(\x0b2\x18.tendermint.crypto.ProofB\x04\xc8\xde\x1f\x00"W\n\x07BlockID\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12>\n\x0fpart_set_header\x18\x02 \x01(\x0b2\x1f.tendermint.types.PartSetHeaderB\x04\xc8\xde\x1f\x00"\xb3\x03\n\x06Header\x124\n\x07version\x18\x01 \x01(\x0b2\x1d.tendermint.version.ConsensusB\x04\xc8\xde\x1f\x00\x12\x1d\n\x08chain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07ChainID\x12\x0e\n\x06height\x18\x03 \x01(\x03\x122\n\x04time\x18\x04 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x126\n\rlast_block_id\x18\x05 \x01(\x0b2\x19.tendermint.types.BlockIDB\x04\xc8\xde\x1f\x00\x12\x18\n\x10last_commit_hash\x18\x06 \x01(\x0c\x12\x11\n\tdata_hash\x18\x07 \x01(\x0c\x12\x17\n\x0fvalidators_hash\x18\x08 \x01(\x0c\x12\x1c\n\x14next_validators_hash\x18\t \x01(\x0c\x12\x16\n\x0econsensus_hash\x18\n \x01(\x0c\x12\x10\n\x08app_hash\x18\x0b \x01(\x0c\x12\x19\n\x11last_results_hash\x18\x0c \x01(\x0c\x12\x15\n\revidence_hash\x18\r \x01(\x0c\x12\x18\n\x10proposer_address\x18\x0e \x01(\x0c"\x13\n\x04Data\x12\x0b\n\x03txs\x18\x01 \x03(\x0c"\x92\x02\n\x04Vote\x12-\n\x04type\x18\x01 \x01(\x0e2\x1f.tendermint.types.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12<\n\x08block_id\x18\x04 \x01(\x0b2\x19.tendermint.types.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07BlockID\x127\n\ttimestamp\x18\x05 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x19\n\x11validator_address\x18\x06 \x01(\x0c\x12\x17\n\x0fvalidator_index\x18\x07 \x01(\x05\x12\x11\n\tsignature\x18\x08 \x01(\x0c"\x9c\x01\n\x06Commit\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12<\n\x08block_id\x18\x03 \x01(\x0b2\x19.tendermint.types.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07BlockID\x125\n\nsignatures\x18\x04 \x03(\x0b2\x1b.tendermint.types.CommitSigB\x04\xc8\xde\x1f\x00"\xa8\x01\n\tCommitSig\x124\n\rblock_id_flag\x18\x01 \x01(\x0e2\x1d.tendermint.types.BlockIDFlag\x12\x19\n\x11validator_address\x18\x02 \x01(\x0c\x127\n\ttimestamp\x18\x03 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x11\n\tsignature\x18\x04 \x01(\x0c"\xf5\x01\n\x08Proposal\x12-\n\x04type\x18\x01 \x01(\x0e2\x1f.tendermint.types.SignedMsgType\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12\r\n\x05round\x18\x03 \x01(\x05\x12\x11\n\tpol_round\x18\x04 \x01(\x05\x12<\n\x08block_id\x18\x05 \x01(\x0b2\x19.tendermint.types.BlockIDB\x0f\xe2\xde\x1f\x07BlockID\xc8\xde\x1f\x00\x127\n\ttimestamp\x18\x06 \x01(\x0b2\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x11\n\tsignature\x18\x07 \x01(\x0c"b\n\x0cSignedHeader\x12(\n\x06header\x18\x01 \x01(\x0b2\x18.tendermint.types.Header\x12(\n\x06commit\x18\x02 \x01(\x0b2\x18.tendermint.types.Commit"z\n\nLightBlock\x125\n\rsigned_header\x18\x01 \x01(\x0b2\x1e.tendermint.types.SignedHeader\x125\n\rvalidator_set\x18\x02 \x01(\x0b2\x1e.tendermint.types.ValidatorSet"\x9e\x01\n\tBlockMeta\x12<\n\x08block_id\x18\x01 \x01(\x0b2\x19.tendermint.types.BlockIDB\x0f\xe2\xde\x1f\x07BlockID\xc8\xde\x1f\x00\x12\x12\n\nblock_size\x18\x02 \x01(\x03\x12.\n\x06header\x18\x03 \x01(\x0b2\x18.tendermint.types.HeaderB\x04\xc8\xde\x1f\x00\x12\x0f\n\x07num_txs\x18\x04 \x01(\x03"S\n\x07TxProof\x12\x11\n\troot_hash\x18\x01 \x01(\x0c\x12\x0c\n\x04data\x18\x02 \x01(\x0c\x12\'\n\x05proof\x18\x03 \x01(\x0b2\x18.tendermint.crypto.Proof*\xd7\x01\n\x0bBlockIDFlag\x121\n\x15BLOCK_ID_FLAG_UNKNOWN\x10\x00\x1a\x16\x8a\x9d \x12BlockIDFlagUnknown\x12/\n\x14BLOCK_ID_FLAG_ABSENT\x10\x01\x1a\x15\x8a\x9d \x11BlockIDFlagAbsent\x12/\n\x14BLOCK_ID_FLAG_COMMIT\x10\x02\x1a\x15\x8a\x9d \x11BlockIDFlagCommit\x12)\n\x11BLOCK_ID_FLAG_NIL\x10\x03\x1a\x12\x8a\x9d \x0eBlockIDFlagNil\x1a\x08\xa8\xa4\x1e\x01\x88\xa3\x1e\x00*\xd7\x01\n\rSignedMsgType\x12,\n\x17SIGNED_MSG_TYPE_UNKNOWN\x10\x00\x1a\x0f\x8a\x9d \x0bUnknownType\x12,\n\x17SIGNED_MSG_TYPE_PREVOTE\x10\x01\x1a\x0f\x8a\x9d \x0bPrevoteType\x120\n\x19SIGNED_MSG_TYPE_PRECOMMIT\x10\x02\x1a\x11\x8a\x9d \rPrecommitType\x12.\n\x18SIGNED_MSG_TYPE_PROPOSAL\x10 \x1a\x10\x8a\x9d \x0cProposalType\x1a\x08\xa8\xa4\x1e\x01\x88\xa3\x1e\x00B9Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.types_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z7github.com/tendermint/tendermint/proto/tendermint/types'
    _BLOCKIDFLAG._options = None
    _BLOCKIDFLAG._serialized_options = b'\xa8\xa4\x1e\x01\x88\xa3\x1e\x00'
    _BLOCKIDFLAG.values_by_name['BLOCK_ID_FLAG_UNKNOWN']._options = None
    _BLOCKIDFLAG.values_by_name['BLOCK_ID_FLAG_UNKNOWN']._serialized_options = b'\x8a\x9d \x12BlockIDFlagUnknown'
    _BLOCKIDFLAG.values_by_name['BLOCK_ID_FLAG_ABSENT']._options = None
    _BLOCKIDFLAG.values_by_name['BLOCK_ID_FLAG_ABSENT']._serialized_options = b'\x8a\x9d \x11BlockIDFlagAbsent'
    _BLOCKIDFLAG.values_by_name['BLOCK_ID_FLAG_COMMIT']._options = None
    _BLOCKIDFLAG.values_by_name['BLOCK_ID_FLAG_COMMIT']._serialized_options = b'\x8a\x9d \x11BlockIDFlagCommit'
    _BLOCKIDFLAG.values_by_name['BLOCK_ID_FLAG_NIL']._options = None
    _BLOCKIDFLAG.values_by_name['BLOCK_ID_FLAG_NIL']._serialized_options = b'\x8a\x9d \x0eBlockIDFlagNil'
    _SIGNEDMSGTYPE._options = None
    _SIGNEDMSGTYPE._serialized_options = b'\xa8\xa4\x1e\x01\x88\xa3\x1e\x00'
    _SIGNEDMSGTYPE.values_by_name['SIGNED_MSG_TYPE_UNKNOWN']._options = None
    _SIGNEDMSGTYPE.values_by_name['SIGNED_MSG_TYPE_UNKNOWN']._serialized_options = b'\x8a\x9d \x0bUnknownType'
    _SIGNEDMSGTYPE.values_by_name['SIGNED_MSG_TYPE_PREVOTE']._options = None
    _SIGNEDMSGTYPE.values_by_name['SIGNED_MSG_TYPE_PREVOTE']._serialized_options = b'\x8a\x9d \x0bPrevoteType'
    _SIGNEDMSGTYPE.values_by_name['SIGNED_MSG_TYPE_PRECOMMIT']._options = None
    _SIGNEDMSGTYPE.values_by_name['SIGNED_MSG_TYPE_PRECOMMIT']._serialized_options = b'\x8a\x9d \rPrecommitType'
    _SIGNEDMSGTYPE.values_by_name['SIGNED_MSG_TYPE_PROPOSAL']._options = None
    _SIGNEDMSGTYPE.values_by_name['SIGNED_MSG_TYPE_PROPOSAL']._serialized_options = b'\x8a\x9d \x0cProposalType'
    _PART.fields_by_name['proof']._options = None
    _PART.fields_by_name['proof']._serialized_options = b'\xc8\xde\x1f\x00'
    _BLOCKID.fields_by_name['part_set_header']._options = None
    _BLOCKID.fields_by_name['part_set_header']._serialized_options = b'\xc8\xde\x1f\x00'
    _HEADER.fields_by_name['version']._options = None
    _HEADER.fields_by_name['version']._serialized_options = b'\xc8\xde\x1f\x00'
    _HEADER.fields_by_name['chain_id']._options = None
    _HEADER.fields_by_name['chain_id']._serialized_options = b'\xe2\xde\x1f\x07ChainID'
    _HEADER.fields_by_name['time']._options = None
    _HEADER.fields_by_name['time']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _HEADER.fields_by_name['last_block_id']._options = None
    _HEADER.fields_by_name['last_block_id']._serialized_options = b'\xc8\xde\x1f\x00'
    _VOTE.fields_by_name['block_id']._options = None
    _VOTE.fields_by_name['block_id']._serialized_options = b'\xc8\xde\x1f\x00\xe2\xde\x1f\x07BlockID'
    _VOTE.fields_by_name['timestamp']._options = None
    _VOTE.fields_by_name['timestamp']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _COMMIT.fields_by_name['block_id']._options = None
    _COMMIT.fields_by_name['block_id']._serialized_options = b'\xc8\xde\x1f\x00\xe2\xde\x1f\x07BlockID'
    _COMMIT.fields_by_name['signatures']._options = None
    _COMMIT.fields_by_name['signatures']._serialized_options = b'\xc8\xde\x1f\x00'
    _COMMITSIG.fields_by_name['timestamp']._options = None
    _COMMITSIG.fields_by_name['timestamp']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _PROPOSAL.fields_by_name['block_id']._options = None
    _PROPOSAL.fields_by_name['block_id']._serialized_options = b'\xe2\xde\x1f\x07BlockID\xc8\xde\x1f\x00'
    _PROPOSAL.fields_by_name['timestamp']._options = None
    _PROPOSAL.fields_by_name['timestamp']._serialized_options = b'\xc8\xde\x1f\x00\x90\xdf\x1f\x01'
    _BLOCKMETA.fields_by_name['block_id']._options = None
    _BLOCKMETA.fields_by_name['block_id']._serialized_options = b'\xe2\xde\x1f\x07BlockID\xc8\xde\x1f\x00'
    _BLOCKMETA.fields_by_name['header']._options = None
    _BLOCKMETA.fields_by_name['header']._serialized_options = b'\xc8\xde\x1f\x00'
    _BLOCKIDFLAG._serialized_start = 2207
    _BLOCKIDFLAG._serialized_end = 2422
    _SIGNEDMSGTYPE._serialized_start = 2425
    _SIGNEDMSGTYPE._serialized_end = 2640
    _PARTSETHEADER._serialized_start = 202
    _PARTSETHEADER._serialized_end = 246
    _PART._serialized_start = 248
    _PART._serialized_end = 331
    _BLOCKID._serialized_start = 333
    _BLOCKID._serialized_end = 420
    _HEADER._serialized_start = 423
    _HEADER._serialized_end = 858
    _DATA._serialized_start = 860
    _DATA._serialized_end = 879
    _VOTE._serialized_start = 882
    _VOTE._serialized_end = 1156
    _COMMIT._serialized_start = 1159
    _COMMIT._serialized_end = 1315
    _COMMITSIG._serialized_start = 1318
    _COMMITSIG._serialized_end = 1486
    _PROPOSAL._serialized_start = 1489
    _PROPOSAL._serialized_end = 1734
    _SIGNEDHEADER._serialized_start = 1736
    _SIGNEDHEADER._serialized_end = 1834
    _LIGHTBLOCK._serialized_start = 1836
    _LIGHTBLOCK._serialized_end = 1958
    _BLOCKMETA._serialized_start = 1961
    _BLOCKMETA._serialized_end = 2119
    _TXPROOF._serialized_start = 2121
    _TXPROOF._serialized_end = 2204




'Generated protocol buffer code.'
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n"cosmos/params/v1beta1/params.proto\x12\x15cosmos.params.v1beta1\x1a\x14gogoproto/gogo.proto"\x82\x01\n\x17ParameterChangeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x129\n\x07changes\x18\x03 \x03(\x0b2".cosmos.params.v1beta1.ParamChangeB\x04\xc8\xde\x1f\x00:\x08\x88\xa0\x1f\x00\x98\xa0\x1f\x00"A\n\x0bParamChange\x12\x10\n\x08subspace\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t:\x04\x98\xa0\x1f\x00B:Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal\xa8\xe2\x1e\x01b\x06proto3')
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.params.v1beta1.params_pb2', globals())
if (_descriptor._USE_C_DESCRIPTORS == False):
    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z4github.com/cosmos/cosmos-sdk/x/params/types/proposal\xa8\xe2\x1e\x01'
    _PARAMETERCHANGEPROPOSAL.fields_by_name['changes']._options = None
    _PARAMETERCHANGEPROPOSAL.fields_by_name['changes']._serialized_options = b'\xc8\xde\x1f\x00'
    _PARAMETERCHANGEPROPOSAL._options = None
    _PARAMETERCHANGEPROPOSAL._serialized_options = b'\x88\xa0\x1f\x00\x98\xa0\x1f\x00'
    _PARAMCHANGE._options = None
    _PARAMCHANGE._serialized_options = b'\x98\xa0\x1f\x00'
    _PARAMETERCHANGEPROPOSAL._serialized_start = 84
    _PARAMETERCHANGEPROPOSAL._serialized_end = 214
    _PARAMCHANGE._serialized_start = 216
    _PARAMCHANGE._serialized_end = 281
